# coding: utf-8

"""
    Finnhub API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from finnhub.configuration import Configuration


class Investor(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'name': 'str',
        'share': 'int',
        'turnover': 'str',
        'turnover_percent': 'float',
        'change': 'int',
        'filing_date': 'date'
    }

    attribute_map = {
        'name': 'name',
        'share': 'share',
        'turnover': 'turnover',
        'turnover_percent': 'turnoverPercent',
        'change': 'change',
        'filing_date': 'filingDate'
    }

    def __init__(self, name=None, share=None, turnover=None, turnover_percent=None, change=None, filing_date=None, local_vars_configuration=None):  # noqa: E501
        """Investor - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._name = None
        self._share = None
        self._turnover = None
        self._turnover_percent = None
        self._change = None
        self._filing_date = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if share is not None:
            self.share = share
        if turnover is not None:
            self.turnover = turnover
        if turnover_percent is not None:
            self.turnover_percent = turnover_percent
        if change is not None:
            self.change = change
        if filing_date is not None:
            self.filing_date = filing_date

    @property
    def name(self):
        """Gets the name of this Investor.  # noqa: E501

        Investor's name.  # noqa: E501

        :return: The name of this Investor.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Investor.

        Investor's name.  # noqa: E501

        :param name: The name of this Investor.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def share(self):
        """Gets the share of this Investor.  # noqa: E501

        Number of shares held by the investor.  # noqa: E501

        :return: The share of this Investor.  # noqa: E501
        :rtype: int
        """
        return self._share

    @share.setter
    def share(self, share):
        """Sets the share of this Investor.

        Number of shares held by the investor.  # noqa: E501

        :param share: The share of this Investor.  # noqa: E501
        :type: int
        """

        self._share = share

    @property
    def turnover(self):
        """Gets the turnover of this Investor.  # noqa: E501

        Turnover rating of the investor.  # noqa: E501

        :return: The turnover of this Investor.  # noqa: E501
        :rtype: str
        """
        return self._turnover

    @turnover.setter
    def turnover(self, turnover):
        """Sets the turnover of this Investor.

        Turnover rating of the investor.  # noqa: E501

        :param turnover: The turnover of this Investor.  # noqa: E501
        :type: str
        """

        self._turnover = turnover

    @property
    def turnover_percent(self):
        """Gets the turnover_percent of this Investor.  # noqa: E501

        Trading's values relative to investor's assets expressed in percentage.  # noqa: E501

        :return: The turnover_percent of this Investor.  # noqa: E501
        :rtype: float
        """
        return self._turnover_percent

    @turnover_percent.setter
    def turnover_percent(self, turnover_percent):
        """Sets the turnover_percent of this Investor.

        Trading's values relative to investor's assets expressed in percentage.  # noqa: E501

        :param turnover_percent: The turnover_percent of this Investor.  # noqa: E501
        :type: float
        """

        self._turnover_percent = turnover_percent

    @property
    def change(self):
        """Gets the change of this Investor.  # noqa: E501

        Number of share changed (net buy or sell) from the last period.  # noqa: E501

        :return: The change of this Investor.  # noqa: E501
        :rtype: int
        """
        return self._change

    @change.setter
    def change(self, change):
        """Sets the change of this Investor.

        Number of share changed (net buy or sell) from the last period.  # noqa: E501

        :param change: The change of this Investor.  # noqa: E501
        :type: int
        """

        self._change = change

    @property
    def filing_date(self):
        """Gets the filing_date of this Investor.  # noqa: E501

        Filing date.  # noqa: E501

        :return: The filing_date of this Investor.  # noqa: E501
        :rtype: date
        """
        return self._filing_date

    @filing_date.setter
    def filing_date(self, filing_date):
        """Sets the filing_date of this Investor.

        Filing date.  # noqa: E501

        :param filing_date: The filing_date of this Investor.  # noqa: E501
        :type: date
        """

        self._filing_date = filing_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Investor):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Investor):
            return True

        return self.to_dict() != other.to_dict()
